==> trabucco_1.3.orig.tar.gz: trabucco1.3/CODE_OF_CONDUCT.md <==
International code of conduct
=============================

No USA cultural imperialism allowed
-----------------------------------

This project welcomes every contributor from any background. For this reason we can't let the USA and USA influenced politically correct culture dictate conduct for everyone. Diversity is beautiful, let's not ask of people to forgo their culture to contribute.

Achieving social justice is important. Being superficial about it only to feel morally superior is not the way to achieve it and is not tolerated here.


The code of conduct only pertains this project
----------------------------------------------

This document only applies to the project and the communication channels.

It does not apply to anything any contributor might say or do outside of project channels.

It only applies to contributors. People whose only contribution is a code of conduct complaint are not contributors.


Language
--------

Try to be nice and constructive.

Harassing and intentionally offending other people is not allowed.

Foul language is allowed.

People often contribute to this project in their own time and are not paid, for this reason asking contributors to behave "professionally" makes no sense. Hobbies do not require professionality.

Jokes are allowed.

It can happen to unintentionally offend someone. Do not reiterate the offensive behaviour, provided that the request is reasonable.

People who are easily offended by things not intended to be offensive must try to become more tolerant towards other people, other cultures and their ways of expressing themselves.

For example, a person might consider offensive the sight of a woman with or without a headscarf. This person needs to try to become more tolerant to other people's culture.

It is not allowed to be offended on behalf of others. Please do not presume to know what others are thinking.

Examples of allowed language:

* This software is retarded
* This program runs like shit
* This bug is annoying

Examples of disallowed language:

* You are retarded
* You are shitty and so is your program


Skill discrimination is absolutely fine
---------------------------------------

Unlike other code of conducts, this allows skill discrimination.

Everyone is welcome to contribute according to their skill level and more experienced contributors are encouraged to act as mentors.

It is nice if they have time and patience to mentor potential contributors, but since time is a limited resource, it is also fine to turn down low quality and low effort contributions with little explaination.

New contributors are expected to respond to comments and be willing to improve the quality of their contribution.

Conflict resolution
-------------------

This code of conduct is inevitably vague. Follow the intention rather than the letter.

The final word rests with the project owners or their delegates.


Changes to license
------------------

It is not allowed to ask for license change and complain about copyleft.

If you disagree with the license, feel free to start your own project from scratch without getting in touch and never look at the source code, to avoid copyright issues.

See also
--------

* International code of conduct: https://github.com/ltworf/international_code_of_conduct

==> trabucco_1.6.orig.tar.gz: trabucco1.6/CODE_OF_CONDUCT.md <==
International code of conduct
=============================

No USA cultural imperialism allowed
-----------------------------------

This project welcomes every contributor from any background. For this reason we can't let the USA and USA influenced politically correct culture dictate conduct for everyone. Diversity is beautiful, let's not ask of people to forgo their culture to contribute.

Achieving social justice is important. Being superficial about it only to feel morally superior is not the way to achieve it and is not tolerated here.


The code of conduct only pertains this project
----------------------------------------------

This document only applies to the project and the communication channels.

It does not apply to anything any contributor might say or do outside of project channels.

It only applies to contributors. People whose only contribution is a code of conduct complaint are not contributors.


Language
--------

Try to be nice and constructive.

Harassing and intentionally offending other people is not allowed.

Foul language is allowed.

People often contribute to this project in their own time and are not paid, for this reason asking contributors to behave "professionally" makes no sense. Hobbies do not require professionality.

Jokes are allowed.

It can happen to unintentionally offend someone. Do not reiterate the offensive behaviour, provided that the request is reasonable.

People who are easily offended by things not intended to be offensive must try to become more tolerant towards other people, other cultures and their ways of expressing themselves.

For example, a person might consider offensive the sight of a woman with or without a headscarf. This person needs to try to become more tolerant to other people's culture.

It is not allowed to be offended on behalf of others. Please do not presume to know what others are thinking.

Examples of allowed language:

* This software is retarded
* This program runs like shit
* This bug is annoying

Examples of disallowed language:

* You are retarded
* You are shitty and so is your program


Skill discrimination is absolutely fine
---------------------------------------

Unlike other code of conducts, this allows skill discrimination.

Everyone is welcome to contribute according to their skill level and more experienced contributors are encouraged to act as mentors.

It is nice if they have time and patience to mentor potential contributors, but since time is a limited resource, it is also fine to turn down low quality and low effort contributions with little explaination.

New contributors are expected to respond to comments and be willing to improve the quality of their contribution.

Conflict resolution
-------------------

This code of conduct is inevitably vague. Follow the intention rather than the letter.

The final word rests with the project owners or their delegates.


Changes to license
------------------

It is not allowed to ask for license change and complain about copyleft.

If you disagree with the license, feel free to start your own project from scratch without getting in touch and never look at the source code, to avoid copyright issues.

See also
--------

* International code of conduct: https://codeberg.org/ltworf/international_code_of_conduct
